@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -91,7 +87,7 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "BMD", "$BM" },
             { "BND", "$BN" },
             { "BOB", "BOB" },
-            { "BSD", "$BS" },
+            { "BSD", "BSD" },
             { "BTN", "BTN" },
             { "BWP", "BWP" },
             { "BYN", "BYN" },
@@ -101,6 +97,7 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "CDF", "CDF" },
             { "CHF", "CHF" },
             { "CLP", "$CL" },
+            { "CNH", "CNH" },
             { "CNY", "CNY" },
             { "COP", "$CO" },
             { "CRC", "CRC" },
@@ -165,6 +162,7 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "MNT", "MNT" },
             { "MOP", "MOP" },
             { "MRO", "MRO" },
+            { "MRU", "MRU" },
             { "MTP", "\u00a3MT" },
             { "MUR", "MUR" },
             { "MVR", "MVR" },
@@ -204,6 +202,7 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "SRD", "$SR" },
             { "SSP", "SSP" },
             { "STD", "STD" },
+            { "STN", "STN" },
             { "SYP", "SYP" },
             { "SZL", "SZL" },
             { "THB", "THB" },
@@ -221,8 +220,9 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "UYU", "$UY" },
             { "UZS", "UZS" },
             { "VEF", "VEF" },
+            { "VES", "VES" },
             { "VUV", "VUV" },
-            { "WST", "WS$" },
+            { "WST", "$WS" },
             { "XCD", "XCD" },
             { "XPF", "FCFP" },
             { "YER", "YER" },
@@ -457,7 +457,7 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "tpe", "escudo timorais" },
             { "trl", "livre turque (1844\u20132005)" },
             { "try", "livre turque" },
-            { "ttd", "dollar trinidadien" },
+            { "ttd", "dollar de Trinit\u00e9-et-Tobago" },
             { "twd", "nouveau dollar ta\u00efwanais" },
             { "tzs", "shilling tanzanien" },
             { "uah", "hryvnia ukrainienne" },
@@ -472,7 +472,8 @@ public class CurrencyNames_fr extends OpenListResourceBundle {
             { "uyu", "peso uruguayen" },
             { "uzs", "sum ouzbek" },
             { "veb", "bolivar v\u00e9n\u00e9zu\u00e9lien (1871\u20132008)" },
-            { "vef", "bolivar v\u00e9n\u00e9zu\u00e9lien" },
+            { "vef", "bolivar v\u00e9n\u00e9zu\u00e9lien (2008\u20132018)" },
+            { "ves", "bolivar v\u00e9n\u00e9zu\u00e9lien" },
             { "vnd", "d\u00f4ng vietnamien" },
             { "vuv", "vatu vanuatuan" },
             { "wst", "tala samoan" },
