@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -198,7 +198,7 @@ public class LocaleNames_uz extends OpenListResourceBundle {
             { "ET", "Efiopiya" },
             { "EU", "Yevropa Ittifoqi" },
             { "type.ca.gregorian", "grigorian taqvimi" },
-            { "EZ", "yevrozona" },
+            { "EZ", "Yevrozona" },
             { "chy", "cheyenn" },
             { "type.nu.gujr", "gujarot raqamlari" },
             { "ady", "adigey" },
@@ -228,6 +228,7 @@ public class LocaleNames_uz extends OpenListResourceBundle {
             { "GT", "Gvatemala" },
             { "GU", "Guam" },
             { "GW", "Gvineya-Bisau" },
+            { "rhg", "rohinja" },
             { "tlh", "klingon" },
             { "GY", "Gayana" },
             { "ckb", "sorani-kurd" },
@@ -652,6 +653,7 @@ public class LocaleNames_uz extends OpenListResourceBundle {
             { "iu", "inuktitut" },
             { "ja", metaValue_ja },
             { "Mlym", metaValue_ml },
+            { "doi", "dogri" },
             { "sma", "janubiy saam" },
             { "jv", "yavan" },
             { "mad", "madur" },
@@ -713,6 +715,7 @@ public class LocaleNames_uz extends OpenListResourceBundle {
             { "ng", "ndonga" },
             { "nl", "niderland" },
             { "nn", "norveg-nyunorsk" },
+            { "no", "norveg" },
             { "nr", "janubiy ndebel" },
             { "nv", "navaxo" },
             { "ny", "cheva" },
