@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -278,6 +274,14 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
                "tongaski \u010das",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Yukonowy \u010das",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "alaskaski standardny \u010das",
                "",
@@ -446,6 +450,14 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
                "chathamski \u010das",
                "",
             };
+        final String[] ETC_UTC = new String[] {
+               "koordinowany sw\u011btowy \u010das",
+               "UTC",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Ecuador = new String[] {
                "ekwadorski \u010das",
                "",
@@ -726,14 +738,6 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
                "\u010das kupy Lord-Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "\u010das kupy Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "marquesaski \u010das",
                "",
@@ -798,14 +802,6 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
                "kapverdski \u010das",
                "",
             };
-        final String[] EMPTY_ZONE = new String[] {
-               "",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] East_Timor = new String[] {
                "wuchodnotimorski \u010das",
                "",
@@ -1224,7 +1220,7 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC", EMPTY_ZONE },
+            { "UTC", ETC_UTC },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
             { "ART", Europe_Eastern },
@@ -1249,6 +1245,7 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UTC", ETC_UTC },
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
             { "Asia/Aden", Arabian },
@@ -1267,7 +1264,7 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Aqtobe", Kazakhstan_Western },
@@ -1415,7 +1412,7 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1490,7 +1487,7 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1539,7 +1536,6 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1575,7 +1571,7 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1619,7 +1615,7 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1659,7 +1655,7 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1705,7 +1701,9 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Cairo", "Kairo" },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
             { "timezone.excity.Asia/Bishkek", "Bi\u0161kek" },
+            { "timezone.excity.Asia/Karachi", "Kara\u010di" },
             { "timezone.excity.Asia/Nicosia", "Nikosia" },
+            { "timezone.excity.Asia/Rangoon", "Rangun" },
             { "timezone.excity.Asia/Tbilisi", "Tbilisi" },
             { "timezone.excity.Asia/Yakutsk", "Jakutsk" },
             { "timezone.excity.Asia/Yerevan", "Jerjewan" },
