@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -274,6 +274,14 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
                "Tonga vaqti",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Yukon vaqti",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "Alyaska standart vaqti",
                "",
@@ -1256,7 +1264,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Aqtobe", Kazakhstan_Western },
@@ -1404,7 +1412,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1479,7 +1487,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1563,7 +1571,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1607,7 +1615,7 @@ public class TimeZoneNames_uz extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
